@@ -2,25 +2,33 @@ import inspect
 import json
 import re
 from pathlib import Path
+from posixpath import expanduser
 from typing import Dict, List
 
-import docker
-from flask import Flask
-from flask import request as flask_request
-from flask_json import JsonError, as_json
 from loguru import logger
-from requests_toolbelt import MultipartDecoder
+
+try:
+    import docker
+    from flask import Flask
+    from flask import request as flask_request
+    from flask_json import JsonError, as_json
+    from requests_toolbelt import MultipartDecoder
+except:
+    raise ImportError(
+        "Extra dependencies need to be install to use the FlaskService class. Please run: `pip install elg[provider]`."
+    )
 
 from .model import AudioRequest, StructuredTextRequest, TextRequest
-from .utils.docker import COPY_FOLDER, DOCKERFILE, ENTRYPOINT
+from .utils.docker import COPY_FOLDER, DOCKERFILE, ENTRYPOINT_FLASK
 
 
 class FlaskService:
     """
-    Class to help the creation of an ELG compatible service from a python model
+    Class to help the creation of an ELG compatible service from a python model.
+    Extra dependencies need to be install to use the FlaskService class. Please run: `pip install elg[provider]`.
     """
 
-    requirements = ["Flask", "Flask-JSON", "gunicorn", "elg", "docker", "flask", "flask_json"]
+    requirements = ["gunicorn", "elg[flask]"]
 
     def __init__(self, name: str):
         """
@@ -77,7 +85,7 @@ class FlaskService:
         logger.info(f"Call with the input: {request}")
         response = self.process_request(request)
         logger.info(f"Get response: {response}")
-        response = {"response": response.dict()}
+        response = {"response": response.dict(by_alias=True)}
         logger.info(f"Return: {response}")
         return response
 
@@ -163,8 +171,11 @@ class FlaskService:
             [COPY_FOLDER.format(folder_name=str(Path(folder))) for folder in required_folders]
         )
         service_script = path.name[:-3]  # to remove .py
-        with open(path.parent / "docker-entrypoint.sh", "w") as f:
-            f.write(ENTRYPOINT.format(service_script=service_script))
+        # The docker-entrypoint file is a Linux shell script so _must_ be
+        # written with Unix-style line endings, even if the build is being done
+        # on Windows.  To ensure this we write in binary mode.
+        with open(path.parent / "docker-entrypoint.sh", "wb") as f:
+            f.write(ENTRYPOINT_FLASK.format(service_script=service_script).encode("utf-8"))
         with open(path.parent / "Dockerfile", "w") as f:
             f.write(DOCKERFILE.format(required_files=" ".join(required_files), required_folders=required_folders))
 
