@@ -435,13 +435,13 @@ class Service(Entity, NeedAuthentication):
                     ),
                     "application/json",
                 ),
-                "content": (None, request.content, "audio/x-wav" if request.format == "linear16" else "audio/mpeg"),
+                "content": (None, request.content, "audio/x-wav" if request.format == "LINEAR16" else "audio/mpeg"),
             }
             data = None
             post_kwargs = {"files": files}
         elif isinstance(request, AudioRequest):
             data = request.content
-            headers["Content-Type"] = "audio/x-wav" if request.format == "linear16" else "audio/mpeg"
+            headers["Content-Type"] = "audio/x-wav" if request.format == "LINEAR16" else "audio/mpeg"
         elif isinstance(request, TextRequest) or isinstance(request, StructuredTextRequest):
             data = json.dumps(request.dict())
             headers["Content-Type"] = "application/json"
